@@ -87,11 +87,6 @@ class Widget(MessagePump):
     def is_visual(self) -> bool:
         return True
 
-    @property
-    def app(self) -> "App":
-        """Get the current app."""
-        return active_app.get()
-
     @property
     def console(self) -> Console:
         """Get the current console."""
